@@ -17,7 +17,6 @@ from gi.repository import Gio
 from gi.repository import GLib
 from nbxmpp.const import ConnectionProtocol
 from nbxmpp.const import ConnectionType
-from nbxmpp.http import HTTPRequest
 from nbxmpp.protocol import JID
 from packaging.version import Version as V
 
@@ -30,7 +29,6 @@ from gajim.common import passwords
 from gajim.common.cert_store import CertificateStore
 from gajim.common.client import Client
 from gajim.common.commands import ChatCommands
-from gajim.common.dbus import file_manager
 from gajim.common.dbus import logind
 from gajim.common.events import AccountCreated
 from gajim.common.events import AccountDisabled
@@ -41,13 +39,16 @@ from gajim.common.events import AllowGajimUpdateCheck
 from gajim.common.events import DBMigrationError
 from gajim.common.events import GajimUpdateAvailable
 from gajim.common.events import SignedIn
+from gajim.common.file_transfer_manager import FileTransfer
+from gajim.common.file_transfer_manager import FileTransferManager
+from gajim.common.multiprocess.http import DownloadResult
 from gajim.common.settings import Settings
 from gajim.common.storage.archive.storage import MessageArchiveStorage
 from gajim.common.storage.cache import CacheStorage
 from gajim.common.storage.draft import DraftStorage
 from gajim.common.storage.events.storage import EventStorage
+from gajim.common.task_manager import PulseManager
 from gajim.common.task_manager import TaskManager
-from gajim.common.util.http import create_http_request
 from gajim.common.util.text import from_one_line
 from gajim.common.util.text import get_random_string
 
@@ -92,6 +93,9 @@ class CoreApplication(ged.EventHelper):
 
         app.cert_store = CertificateStore()
         app.task_manager = TaskManager()
+        app.pulse_manager = PulseManager()
+
+        app.ftm = FileTransferManager()
 
         # from gajim.common.call_manager import CallManager
         # app.call_manager = CallManager()
@@ -109,8 +113,6 @@ class CoreApplication(ged.EventHelper):
         else:
             logind.enable()
 
-        file_manager.init()
-
         for account in app.settings.get_active_accounts():
             app.connections[account] = Client(account)
             app.to_be_removed[account] = []
@@ -316,25 +318,31 @@ class CoreApplication(ged.EventHelper):
     def check_for_gajim_updates(self) -> None:
         self._log.info('Checking for Gajim updates')
 
-        request = create_http_request()
-        request.send('GET', 'https://gajim.org/current-version.json',
-                     callback=self._on_update_response)
+        app.ftm.http_download(
+            'https://gajim.org/current-version.json',
+            callback=self._on_update_response,
+        )
 
-    def _on_update_response(self, request: HTTPRequest) -> None:
-        if not request.is_complete():
+    def _on_update_response(self, obj: FileTransfer[DownloadResult]) -> None:
+        try:
+            result = obj.get_result()
+        except Exception as error:
             self._log.warning(
-                'Error while performing gajim update check: %s (%s)',
-                request.get_error_string(), request.get_status())
+                'Error while performing gajim update check: %s', error)
             return
 
         now = datetime.now()
         app.settings.set('last_update_check', now.strftime('%Y-%m-%d %H:%M'))
 
-        data = json.loads(request.get_data())
-        latest_version = data['current_version']
-        setup_url = data['current_win_setup']
-        if IS_PORTABLE:
-            setup_url = data['current_win_portable_setup']
+        try:
+            data = json.loads(result.content)
+            latest_version = data['current_version']
+            setup_url = data['current_win_setup']
+            if IS_PORTABLE:
+                setup_url = data['current_win_portable_setup']
+        except Exception:
+            self._log.exception("Unable to perform update check")
+            return
 
         if V(latest_version) > V(app.version):
             app.ged.raise_event(GajimUpdateAvailable(version=latest_version,
