@@ -220,16 +220,17 @@ class Contacts(BaseModule):
         contact = contact.get_resource(resource)
         return contact
 
-    def get_bare_contact(self,
-                         jid: str | JID
-                         ) -> BareContact | GroupchatContact:
-        '''This method gives direct access to the contacts dict.
-           This is helpful when performance is essential. In difference to
-           get_contact() this method does not create contacts nor can it handle
-           JIDs which are not bare. Use this only if you know the contact
-           exists.
-        '''
-        return self._contacts[jid]
+    def get_contact_if_exists(
+        self,
+        jid: JID
+    ) -> BareContact | ResourceContact | GroupchatContact | GroupchatParticipant | None:
+        contact = self._contacts.get(jid.new_as_bare())
+        if contact is None:
+            return None
+
+        if jid.resource:
+            return contact.get_resource_if_exists(jid.resource)
+        return contact
 
     def get_contacts_with_domain(self,
                                  domain: str
@@ -424,7 +425,6 @@ class BareContact(CommonContact):
         contact = ResourceContact(self._log, jid, self._account)
         self._resources[resource] = contact
         contact.connect('presence-update', self._on_signal)
-        contact.connect('chatstate-update', self._on_signal)
         contact.connect('nickname-update', self._on_signal)
         contact.connect('caps-update', self._on_signal)
         return contact
@@ -438,6 +438,9 @@ class BareContact(CommonContact):
             contact = self.add_resource(resource)
         return contact
 
+    def get_resource_if_exists(self, resource: str) -> ResourceContact | None:
+        return self._resources.get(resource)
+
     def get_active_resource(self) -> ResourceContact | None:
         if not self._resources:
             return None
@@ -495,15 +498,10 @@ class BareContact(CommonContact):
 
     @property
     def chatstate(self) -> Chatstate | None:
-        chatstates = {contact.chatstate for contact in self._resources.values()}
-        chatstates.discard(None)
-        if not chatstates:
-            return None
-        return min(chatstates)
+        return self.get_module('Chatstate').get_remote_chatstate(self._jid)
 
     def force_chatstate_update(self) -> None:
-        for contact in self._resources.values():
-            contact.notify('chatstate-update')
+        self.notify('chatstate-update')
 
     @property
     def name(self) -> str:
@@ -661,6 +659,13 @@ class BareContact(CommonContact):
 
         return any(r.is_bot for r in self.iter_resources())
 
+    @property
+    def reactions_per_user(self) -> int | None:
+        disco = app.storage.cache.get_last_disco_info(self._jid.domain)
+        if disco is None:
+            return None
+        return disco.reactions_per_user
+
 
 class ResourceContact(CommonContact):
     def __init__(self, logger: LogAdapter, jid: JID, account: str) -> None:
@@ -727,10 +732,6 @@ class ResourceContact(CommonContact):
     def idle_datetime(self) -> datetime | None:
         return self._presence.idle_datetime
 
-    @property
-    def chatstate(self) -> Chatstate | None:
-        return self.get_module('Chatstate').get_remote_chatstate(self._jid)
-
     def update_presence(self,
                         presence_data: PresenceData,
                         notify: bool = True
@@ -819,6 +820,9 @@ class GroupchatContact(CommonContact):
             contact = self.add_resource(resource)
         return contact
 
+    def get_resource_if_exists(self, resource: str) -> GroupchatParticipant | None:
+        return self._resources.get(resource)
+
     def get_participants(self) -> Iterator[GroupchatParticipant]:
         for contact in self._resources.values():
             if contact.is_available:
@@ -952,6 +956,18 @@ class GroupchatContact(CommonContact):
     def get_composers(self) -> list['GroupchatParticipant']:
         return self.get_module('Chatstate').get_composers(self._jid)
 
+    @property
+    def reactions_per_user(self) -> int | None:
+        for entity in (self._jid, self._jid.domain):
+            disco = app.storage.cache.get_last_disco_info(entity)
+            if disco is None:
+                continue
+
+            if disco.reactions_per_user is not None:
+                return disco.reactions_per_user
+
+        return None
+
 
 class GroupchatParticipant(CommonContact):
     def __init__(self, logger: LogAdapter, jid: JID, account: str) -> None:
@@ -989,7 +1005,8 @@ class GroupchatParticipant(CommonContact):
 
     @property
     def room(self) -> GroupchatContact:
-        contact = self.get_module('Contacts').get_bare_contact(self.jid.bare)
+        contact = self.get_module('Contacts').get_contact_if_exists(
+            self.jid.new_as_bare())
         assert isinstance(contact, GroupchatContact)
         return contact
 
@@ -1099,6 +1116,10 @@ class GroupchatParticipant(CommonContact):
         return client.get_module('MucBlocking').is_blocked(
             self.room.jid, self.occupant_id)
 
+    @property
+    def reactions_per_user(self) -> int | None:
+        return self.room.reactions_per_user
+
 
 def can_add_to_roster(contact: BareContact) -> bool:
     if contact.is_self:
