@@ -32,6 +32,7 @@ from gajim.common.i18n import _
 from gajim.common.util.text import process_non_spacing_marks
 
 from gajim.gtk.assistant import Assistant
+from gajim.gtk.assistant import DefaultPage
 from gajim.gtk.assistant import ErrorPage
 from gajim.gtk.assistant import Page
 from gajim.gtk.assistant import ProgressPage
@@ -69,6 +70,7 @@ class AdHocCommands(Assistant):
                 "stage": Stage(),
                 "completed": Completed(),
                 "error": Error(),
+                "end": End(),
                 "executing": Executing(),
             }
         )
@@ -98,6 +100,9 @@ class AdHocCommands(Assistant):
     @overload
     def get_page(self, name: Literal["error"]) -> Error: ...
 
+    @overload
+    def get_page(self, name: Literal["end"]) -> End: ...
+
     @overload
     def get_page(self, name: Literal["executing"]) -> Executing: ...
 
@@ -108,12 +113,19 @@ class AdHocCommands(Assistant):
     def _received_command_list(self, task: Task) -> None:
         try:
             commands = cast(list[AdHocCommand] | None, task.finish())
-        except (StanzaError, MalformedStanzaError) as error:
-            self._set_error(to_user_string(error), False)
+        except StanzaError as error:
+            if error.condition == "feature-not-implemented":
+                commands = []
+            else:
+                self._set_error(to_user_string(error), False)
+                return
+
+        except MalformedStanzaError:
+            self._set_error(_("Invalid server response"), False)
             return
 
         if not commands:
-            self._set_error(_("No commands available"), False)
+            self._set_end(_("No commands available"))
             return
 
         commands_page = self.get_page("commands")
@@ -124,10 +136,14 @@ class AdHocCommands(Assistant):
     def _received_stage(self, task: Task) -> None:
         try:
             stage = cast(AdHocCommand, task.finish())
-        except (StanzaError, MalformedStanzaError) as error:
+        except StanzaError as error:
             self._set_error(to_user_string(error), True)
             return
 
+        except MalformedStanzaError:
+            self._set_error(_("Invalid server response"), False)
+            return
+
         page_name = "stage"
         if stage.is_completed:
             page_name = "completed"
@@ -142,6 +158,11 @@ class AdHocCommands(Assistant):
         error_page.set_text(text)
         self.show_page("error")
 
+    def _set_end(self, text: str = "") -> None:
+        end = self.get_page("end")
+        end.set_text(text)
+        self.show_page("end")
+
     def _cleanup(self) -> None:
         self._destroyed = True
 
@@ -318,7 +339,7 @@ class Stage(Page):
         self._dataform_widget.validate()
         self.append(self._dataform_widget)
 
-    def _show_notes(self, notes: list[AdHocCommandNote] | None):
+    def _show_notes(self, notes: list[AdHocCommandNote] | None) -> None:
         for note in self._notes:
             self.remove(note)
         self._notes = []
@@ -341,9 +362,13 @@ class Stage(Page):
         self.update_page_complete()
 
     def get_visible_buttons(self) -> list[str]:
+        assert self._last_stage_data is not None
+        assert self._last_stage_data.actions is not None
         return [action.value for action in self._last_stage_data.actions]
 
     def get_default_button(self) -> str:
+        assert self._last_stage_data is not None
+        assert self._last_stage_data.default is not None
         return self._last_stage_data.default.value
 
 
@@ -387,7 +412,7 @@ class Completed(Page):
         self._show_notes(stage_data.notes)
         self._show_form(stage_data.data)
         self._show_icon_text(stage_data.data is None)
-        self._show_icon(len(stage_data.notes) <= 1)
+        self._show_icon(len(stage_data.notes or []) <= 1)
 
     def _set_status(self, status: str):
         self.title = status
@@ -419,9 +444,12 @@ class Completed(Page):
         self._dataform_widget = DataFormWidget(form, options={"read-only": True})
         self.append(self._dataform_widget)
 
-    def _show_notes(self, notes: list[AdHocCommandNote]):
+    def _show_notes(self, notes: list[AdHocCommandNote] | None) -> None:
         container_remove_all(self._notes)
 
+        if notes is None:
+            return
+
         for i, note in enumerate(notes):
             if len(notes) > 1:
                 icon = SeverityIcon(note.type)
@@ -471,6 +499,12 @@ class Error(ErrorPage):
         return []
 
 
+class End(DefaultPage):
+    def __init__(self) -> None:
+        DefaultPage.__init__(self)
+        self.title = _("Completed")
+
+
 class Executing(ProgressPage):
     def __init__(self) -> None:
         ProgressPage.__init__(self)
@@ -495,11 +529,11 @@ class SeverityIcon(Gtk.Image):
         self.remove_css_class("warning")
         self.remove_css_class("error")
         if severity == AdHocNoteType.INFO:
-            self.set_from_icon_name("object-select-symbolic")
+            self.set_from_icon_name("lucide-check-symbolic")
             self.add_css_class("success")
         elif severity == AdHocNoteType.WARN:
-            self.set_from_icon_name("dialog-warning-symbolic")
+            self.set_from_icon_name("lucide-circle-alert-symbolic")
             self.add_css_class("warning")
         elif severity == AdHocNoteType.ERROR:
-            self.set_from_icon_name("dialog-error-symbolic")
+            self.set_from_icon_name("lucide-circle-x-symbolic")
             self.add_css_class("error")
