@@ -62,7 +62,7 @@ class Assistant(GObject.Object, GajimAppWindow, EventHelper):
         self._button_visible_func = None
 
         self._ui = get_builder("assistant.ui")
-        self.set_child(self._ui.main_grid)
+        self.set_child(self._ui.main_box)
 
         self._ui.stack.set_transition_duration(transition_duration)
 
@@ -241,7 +241,9 @@ class Page(Gtk.Box, SignalManager):
 
 
 class DefaultPage(Page):
-    def __init__(self, icon_name: str, icon_css_class: str) -> None:
+    def __init__(
+        self, icon_name: str | None = None, icon_css_class: str | None = None
+    ) -> None:
         Page.__init__(self)
 
         self._heading = Gtk.Label(
@@ -251,10 +253,14 @@ class DefaultPage(Page):
             justify=Gtk.Justification.CENTER,
         )
         self._heading.add_css_class("title-1")
+        self.append(self._heading)
 
-        icon = Gtk.Image.new_from_icon_name(icon_name)
-        icon.set_pixel_size(64)
-        icon.add_css_class(icon_css_class)
+        if icon_name is not None:
+            icon = Gtk.Image.new_from_icon_name(icon_name)
+            icon.set_pixel_size(64)
+            if icon_css_class is not None:
+                icon.add_css_class(icon_css_class)
+            self.append(icon)
 
         self._label = Gtk.Label(
             wrap=True,
@@ -262,9 +268,6 @@ class DefaultPage(Page):
             halign=Gtk.Align.CENTER,
             justify=Gtk.Justification.CENTER,
         )
-
-        self.append(self._heading)
-        self.append(icon)
         self.append(self._label)
 
     def set_heading(self, heading: str) -> None:
@@ -280,14 +283,14 @@ class DefaultPage(Page):
 class ErrorPage(DefaultPage):
     def __init__(self) -> None:
         DefaultPage.__init__(
-            self, icon_name="dialog-error-symbolic", icon_css_class="error"
+            self, icon_name="lucide-circle-x-symbolic", icon_css_class="error"
         )
 
 
 class SuccessPage(DefaultPage):
     def __init__(self) -> None:
         DefaultPage.__init__(
-            self, icon_name="object-select-symbolic", icon_css_class="success"
+            self, icon_name="lucide-check-symbolic", icon_css_class="success"
         )
 
 
