@@ -12,9 +12,11 @@ from enum import IntEnum
 from gi.repository import Adw
 from gi.repository import Gdk
 from gi.repository import Gtk
-from nbxmpp.errors import StanzaError
+from nbxmpp.const import Affiliation
+from nbxmpp.const import Role
 from nbxmpp.modules.vcard4 import VCard
 from nbxmpp.namespaces import Namespace
+from nbxmpp.protocol import JID
 from nbxmpp.structs import AnnotationNote
 from nbxmpp.structs import SoftwareVersionResult
 from nbxmpp.task import Task
@@ -77,10 +79,27 @@ class ContactInfo(GajimAppWindow, EventHelper):
 
         EventHelper.__init__(self)
 
-        # Set account and jid for window management
+        # Window management needs both account and contact attributes set
         self.account = account
         self.contact = contact
+
         self._client = app.get_client(account)
+
+        affiliation = None
+        role = None
+        if isinstance(contact, GroupchatParticipant):
+            # Display full contact dialog if we know contact's real JID
+            # (but keep affiliation/role infos)
+            affiliation = contact.affiliation
+            role = contact.role
+
+            if contact.real_jid is not None:
+                bare_contact = self._client.get_module("Contacts").get_contact(
+                    contact.real_jid
+                )
+                assert isinstance(bare_contact, BareContact)
+                self.contact = bare_contact
+
         self._client.connect_signal("state-changed", self._on_client_state_changed)
 
         self._ui = get_builder("contact_info.ui")
@@ -106,20 +125,19 @@ class ContactInfo(GajimAppWindow, EventHelper):
 
         self.set_child(nav)
 
-        self._switcher.set_stack(self._ui.main_stack, rows_visible=False)
+        self._switcher.set_with_stack(self._ui.main_stack, visible=False)
 
         self._load_avatar()
 
         self._contact_name_widget = ContactNameWidget(
-            contact=self.contact, edit_mode=True
+            contact=self.contact, edit_mode=self.contact.is_in_roster
         )
-
         self._connect(
             self._contact_name_widget, "name-updated", self._on_contact_name_updated
         )
         self._ui.contact_name_controls_box.append(self._contact_name_widget)
 
-        self._fill_information_page(self.contact)
+        self._fill_information_page(self.contact, affiliation, role)
 
         if isinstance(self.contact, BareContact):
             self._fill_settings_page(self.contact)
@@ -129,7 +147,9 @@ class ContactInfo(GajimAppWindow, EventHelper):
             self._fill_note_page(self.contact)
 
         if page is not None:
-            self._switcher.set_row(page)
+            self._switcher.activate_item(page)
+        else:
+            self._switcher.activate_item("information")
 
         self._connect(
             self._ui.tree_selection, "changed", self._on_group_selection_changed
@@ -205,7 +225,12 @@ class ContactInfo(GajimAppWindow, EventHelper):
     def _on_contact_name_updated(self, _widget: ContactNameWidget, name: str) -> None:
         self._sidebar_page.set_title(name)
 
-    def _fill_information_page(self, contact: ContactT) -> None:
+    def _fill_information_page(
+        self,
+        contact: ContactT,
+        affiliation: Affiliation | None = None,
+        role: Role | None = None,
+    ) -> None:
         self._vcard_grid = VCardGrid(self.account)
         self._ui.vcard_box.append(self._vcard_grid)
         if self._client.state.is_available:
@@ -218,18 +243,18 @@ class ContactInfo(GajimAppWindow, EventHelper):
         self._ui.contact_jid_label.set_text(jid)
         self._ui.contact_jid_label.set_tooltip_text(jid)
 
-        if isinstance(contact, GroupchatParticipant):
-            self._ui.role_label.set_text(get_uf_role(contact.role))
-            self._ui.affiliation_label.set_text(get_uf_affiliation(contact.affiliation))
+        if affiliation is not None and role is not None:
+            self._ui.affiliation_label.set_text(get_uf_affiliation(affiliation))
+            self._ui.role_label.set_text(get_uf_role(role))
             self._ui.group_chat_grid.set_visible(True)
 
-        self._switcher.set_row_visible("information", True)
+        self._switcher.set_item_visible("information", True)
 
     def _fill_encryption_page(self, contact: ContactT) -> None:
-        self._ui.encryption_box.append(
+        self._ui.encryption_box.set_child(
             OMEMOTrustManager(self.contact.account, self.contact)
         )
-        self._switcher.set_row_visible("encryption-omemo", True)
+        self._switcher.set_item_visible("encryption-omemo", True)
 
     def _fill_note_page(self, contact: BareContact) -> None:
         if not contact.is_in_roster:
@@ -245,13 +270,13 @@ class ContactInfo(GajimAppWindow, EventHelper):
             # roster notes cannot be stored without.
             # Since there is no disco mechanism for private storage, we rely on
             # Delimiter as a "proxy" for the availability of private storage.
-            self._switcher.set_row_visible("notes", True)
+            self._switcher.set_item_visible("notes", True)
 
     def _fill_settings_page(self, contact: BareContact) -> None:
         if not contact.is_in_roster:
             return
 
-        self._ui.from_subscription_switch.set_state(contact.is_subscribed)
+        self._ui.from_subscription_switch.set_active(contact.is_subscribed)
 
         self._ui.subscription_listbox.set_sensitive(self._client.state.is_available)
 
@@ -265,7 +290,7 @@ class ContactInfo(GajimAppWindow, EventHelper):
             self._ui.to_subscription_stack.set_visible_child_name("request")
             self._ui.request_stack.set_visible_child_name("cross")
 
-        self._switcher.set_row_visible("settings", True)
+        self._switcher.set_item_visible("settings", True)
         contact_settings = ContactSettings(self.account, contact.jid)
         self._ui.contact_settings_box.add(contact_settings)
 
@@ -285,7 +310,7 @@ class ContactInfo(GajimAppWindow, EventHelper):
             is_in_group = group in contact.groups
             model.append([is_in_group, group])
 
-        self._switcher.set_row_visible("groups", True)
+        self._switcher.set_item_visible("groups", True)
 
     def _fill_device_info(self, contact: BareContact) -> None:
         contacts = list(contact.iter_resources())
@@ -299,7 +324,7 @@ class ContactInfo(GajimAppWindow, EventHelper):
             self._query_device(resource_contact)
 
         self._ui.devices_stack.set_visible_child_name("devices")
-        self._switcher.set_row_visible("devices", True)
+        self._switcher.set_item_visible("devices", True)
 
     def _query_device(self, contact: ResourceContact) -> None:
         software_module = self._client.get_module("SoftwareVersion")
@@ -313,16 +338,7 @@ class ContactInfo(GajimAppWindow, EventHelper):
         )
         self._tasks.append(task)
 
-    def _on_vcard_received(self, task: Task) -> None:
-        try:
-            vcard = cast(VCard | None, task.finish())
-        except StanzaError as err:
-            log.info("Error loading VCard: %s", err)
-            vcard = None
-
-        if vcard is None:
-            vcard = VCard()
-
+    def _on_vcard_received(self, jid: JID, vcard: VCard) -> None:
         self._vcard_grid.set_vcard(vcard)
 
     def _load_avatar(self) -> None:
@@ -401,7 +417,7 @@ class ContactInfo(GajimAppWindow, EventHelper):
     def _on_to_subscription_button_clicked(self, _widget: Gtk.Button) -> None:
         # Save auto_auth if switch for disclosing presence is active
         self._client.get_module("Presence").subscribe(
-            self.contact.jid, auto_auth=self._ui.from_subscription_switch.get_state()
+            self.contact.jid, auto_auth=self._ui.from_subscription_switch.get_active()
         )
         self._ui.request_stack.set_visible_child_name("requested")
 
