@@ -17,7 +17,6 @@
 # - def _create_treemodel(self) *
 # - def _add_actions(self)
 # - def _clean_actions(self)
-# - def update_theme(self) *
 # - def update_actions(self)
 # - def default_action(self)
 # - def _find_item(self, jid, node)
@@ -38,6 +37,7 @@ from typing import Concatenate
 from typing import Generic
 from typing import TypeVar
 
+import logging
 import types
 import weakref
 from collections.abc import Callable
@@ -45,18 +45,17 @@ from collections.abc import Iterator
 
 from gi.repository import GLib
 from gi.repository import Gtk
-from nbxmpp import Node
-from nbxmpp.client import Client as NBXMPPClient
 from nbxmpp.errors import StanzaError
+from nbxmpp.modules.pubsub import PubSubSubscription
 from nbxmpp.namespaces import Namespace
 from nbxmpp.protocol import JID
 from nbxmpp.structs import DiscoIdentity
 from nbxmpp.structs import DiscoInfo
 from nbxmpp.structs import DiscoItem
 from nbxmpp.structs import DiscoItems
+from nbxmpp.task import Task
 
 from gajim.common import app
-from gajim.common.const import StyleAttr
 from gajim.common.i18n import _
 from gajim.common.util.jid import InvalidFormat
 from gajim.common.util.jid import parse_jid
@@ -71,6 +70,7 @@ from gajim.gtk.widgets import GajimAppWindow
 _T = TypeVar("_T")
 _InfoCacheT = tuple[list[DiscoIdentity], list[str], list[Any]]
 
+log = logging.getLogger("gajim.gtk.discovery")
 
 LABELS = {
     1: _("This service has not yet responded with detailed information"),
@@ -104,6 +104,7 @@ def _gen_agent_type_info():
         ("directory", "user"): (None, "jud"),
         ("pubsub", "generic"): (DiscussionGroupsBrowser, "pubsub"),
         ("pubsub", "service"): (DiscussionGroupsBrowser, "pubsub"),
+        ("pubsub", "pep"): (DiscussionGroupsBrowser, "pubsub"),
         ("proxy", "bytestreams"): (None, "bytestreams"),  # Socks5 FT proxy
         ("headline", "newmail"): (ToplevelAgentBrowser, "mail"),
         # Transports
@@ -611,10 +612,12 @@ class ServiceDiscoveryWindow(GajimAppWindow):
             raise RuntimeError("You must be connected to browse services")
 
         # Get a ServicesCache object.
-        self.cache = cast(ServicesCache, app.services_cache)
-        if app.services_cache is None:
+        cache = app.services_cache.get(account)
+        if cache is None:
             self.cache = ServicesCache(account)
-            app.services_cache = self.cache
+            app.services_cache[account] = self.cache
+        else:
+            self.cache = cast(ServicesCache, cache)
 
         self._ui = get_builder("service_discovery_window.ui")
         self.set_child(self._ui.service_discovery)
@@ -677,13 +680,6 @@ class ServiceDiscoveryWindow(GajimAppWindow):
     def account(self) -> str:
         return self._account
 
-    @account.setter
-    def account(self, value: str) -> None:
-        self._account = value
-        self.cache.account = value
-        if self.browser:
-            self.browser.account = value
-
     def _initial_state(self):
         """
         Set some initial state on the window. Separated in a method because it's
@@ -1033,11 +1029,6 @@ class AgentBrowser:
 
         self.window._initial_state()  # pyright: ignore
 
-    def update_theme(self):
-        """
-        Called when the default theme is changed
-        """
-
     def on_browse_button_clicked(self, _button: Gtk.Button | None = None) -> None:
         """
         When we want to browse an agent: open a new services window with a
@@ -1278,7 +1269,6 @@ class ToplevelAgentBrowser(AgentBrowser):
     def __init__(self, *args: Any):
         AgentBrowser.__init__(self, *args)
         self._progressbar_sourceid = None
-        self._renderer = None
         self._progress = 0
         self.register_button = None
         self.join_button = None
@@ -1337,7 +1327,6 @@ class ToplevelAgentBrowser(AgentBrowser):
         state = model.get_value(iter_, 4)
         cell.set_property("markup", markup)
         if jid:
-            cell.set_property("cell_background_set", False)
             if state is not None:
                 # fetching or error
                 cell.set_property("foreground_set", True)
@@ -1345,9 +1334,6 @@ class ToplevelAgentBrowser(AgentBrowser):
                 # Normal/success
                 cell.set_property("foreground_set", False)
         else:
-            bgcolor = app.css_config.get_value(".gajim-group-row", StyleAttr.BACKGROUND)
-            if bgcolor:
-                cell.set_property("cell_background_set", True)
             cell.set_property("foreground_set", False)
 
     def _treemodel_sort_func(
@@ -1397,9 +1383,6 @@ class ToplevelAgentBrowser(AgentBrowser):
         col.pack_start(renderer, True)
         col.set_cell_data_func(renderer, self._text_renderer_data_func)
         renderer.set_property("foreground", "dark gray")
-        # Save this so we can go along with theme changes
-        self._renderer = renderer
-        self.update_theme()
 
         view.set_tooltip_column(4)
         view.insert_column(col, -1)
@@ -1467,13 +1450,6 @@ class ToplevelAgentBrowser(AgentBrowser):
     def cleanup(self) -> None:
         AgentBrowser.cleanup(self)
 
-    def update_theme(self) -> None:
-        bgcolor = app.css_config.get_value(".gajim-group-row", StyleAttr.BACKGROUND)
-        if bgcolor:
-            assert self._renderer is not None
-            self._renderer.set_property("cell-background", bgcolor)
-        self.window.services_treeview.queue_draw()
-
     def _on_execute_button_clicked(self, _button: Gtk.Button | None = None) -> None:
         """
         When we want to execute a command: open adhoc command window
@@ -2038,8 +2014,8 @@ class DiscussionGroupsBrowser(AgentBrowser):
         self.unsubscribe_button = None
 
         client = app.get_client(account)
-        client.get_module("PubSub").send_pb_subscription_query(
-            jid, self._on_pep_subscriptions
+        client.get_module("PubSub").get_subscriptions(
+            jid, callback=self._on_subscriptions_received
         )
 
     def _create_treemodel(self):
@@ -2193,8 +2169,8 @@ class DiscussionGroupsBrowser(AgentBrowser):
         node = model.get_value(iter_, 1)  # 1 = groupnode
 
         client = app.get_client(self.account)
-        client.get_module("PubSub").send_pb_subscribe(
-            self.jid, node, self._on_pep_subscribe, groupnode=node
+        client.get_module("PubSub").subscribe(
+            node, self.jid, callback=self._on_subscribe_response, user_data=node
         )
 
     def _on_unsubscribe_button_clicked(self, _button: Gtk.Button) -> None:
@@ -2208,31 +2184,22 @@ class DiscussionGroupsBrowser(AgentBrowser):
         node = model.get_value(iter_, 1)  # 1 = groupnode
 
         client = app.get_client(self.account)
-        client.get_module("PubSub").send_pb_unsubscribe(
-            self.jid, node, self._on_pep_unsubscribe, groupnode=node
+        client.get_module("PubSub").unsubscribe(
+            node, self.jid, callback=self._on_unsubscribe_response, user_data=node
         )
 
-    def _on_pep_subscriptions(self, _nbxmpp_client: NBXMPPClient, stanza: Node) -> None:
-        """
-        We got the subscribed groups list stanza. Now, if we already have items
-        on the list, we should actualize them
-        """
-
-        pubsub = stanza.getTag("pubsub")
-        if pubsub is None:
+    def _on_subscriptions_received(self, task: Task) -> None:
+        try:
+            result = cast(list[PubSubSubscription], task.finish())
+        except Exception as error:
+            log.exception("Failed to retrieve subscriptions: %s", error)
             return
 
-        subscriptions = pubsub.getTag("subscriptions")
-        if subscriptions is None:
-            return
+        groups = {sub.node for sub in result}
+        if groups:
+            log.info("Received subscribed nodes: %s", ", ".join(groups))
 
-        groups_: set[str] = set()
-        for child in subscriptions.getTags("subscription"):
-            node = child["node"]
-            assert node is not None
-            groups_.add(node)
-
-        self.subscriptions = groups_
+        self.subscriptions = groups
 
         # Try to setup existing items in model
         model = self.window.services_treeview.get_model()
@@ -2243,17 +2210,23 @@ class DiscussionGroupsBrowser(AgentBrowser):
             # 4 = subscribed?
             groupnode = row[1]
             row[3] = False
-            row[4] = groupnode in groups_
+            row[4] = groupnode in groups
 
         # we now know subscriptions, update button states
         self.update_actions()
 
-    def _on_pep_subscribe(
-        self, _nbxmpp_client: NBXMPPClient, _stanza: Node, groupnode: str
-    ) -> None:
-        """
-        We have just subscribed to a node. Update UI
-        """
+    def _on_subscribe_response(self, task: Task) -> None:
+        groupnode = cast(str, task.get_user_data())
+        try:
+            result = cast(PubSubSubscription, task.finish())
+        except Exception as error:
+            log.exception("Failed to subscribe: %s, %s", groupnode, error)
+            return
+
+        if result.subscription != "subscribed":
+            log.warning("Unhandled subscription value: %s", result.subscription)
+            return
+
         assert self.subscriptions is not None
         self.subscriptions.add(groupnode)
 
@@ -2266,12 +2239,14 @@ class DiscussionGroupsBrowser(AgentBrowser):
 
         self.update_actions()
 
-    def _on_pep_unsubscribe(
-        self, _nbxmpp_client: NBXMPPClient, _stanza: Node, groupnode: str
-    ) -> None:
-        """
-        We have just unsubscribed from a node. Update UI
-        """
+    def _on_unsubscribe_response(self, task: Task) -> None:
+        groupnode = cast(str, task.get_user_data())
+        try:
+            task.finish()
+        except Exception as error:
+            log.exception("Failed to unsubscribe: %s, %s", groupnode, error)
+            return
+
         assert self.subscriptions is not None
         self.subscriptions.remove(groupnode)
 
