@@ -257,6 +257,7 @@ class MessageActionsBox(Gtk.Grid, EventHelper, SignalManager):
 
     def _on_emoji_picked(self, _emoji_chooser: EmojiChooser, text: str) -> None:
         self.msg_textview.insert_text(text)
+        GLib.idle_add(self.msg_textview.grab_focus_delayed)
 
     def _on_action(
         self, action: Gio.SimpleAction, param: GLib.Variant | None
@@ -536,7 +537,7 @@ class MessageActionsBox(Gtk.Grid, EventHelper, SignalManager):
             self._ui.state_box_label.set_text(
                 _("You are offline. Go online to send messages…")
             )
-            self._ui.state_box_image.set_from_icon_name("network-offline-symbolic")
+            self._ui.state_box_image.set_from_icon_name("lucide-cloud-off-symbolic")
 
         if isinstance(self._contact, GroupchatContact):
             state = self._contact.is_joined
@@ -549,7 +550,7 @@ class MessageActionsBox(Gtk.Grid, EventHelper, SignalManager):
                     self._ui.visitor_menu_button.set_visible(True)
                     self._ui.state_box_label.set_text(_("You are a visitor."))
                     self._ui.state_box_image.set_from_icon_name(
-                        "feather-mic-off-symbolic"
+                        "lucide-mic-off-symbolic"
                     )
 
         if isinstance(self._contact, GroupchatParticipant):
@@ -557,7 +558,7 @@ class MessageActionsBox(Gtk.Grid, EventHelper, SignalManager):
             self._ui.state_box_label.set_text(
                 _("You can’t send private messages to contacts if they are offline.")
             )
-            self._ui.state_box_image.set_from_icon_name("network-offline-symbolic")
+            self._ui.state_box_image.set_from_icon_name("lucide-cloud-off-symbolic")
 
         self._ui.state_box.set_visible(not state)
 
@@ -610,12 +611,12 @@ class MessageActionsBox(Gtk.Grid, EventHelper, SignalManager):
             tooltip = _("Choose encryption")
 
             if encryption in ("OMEMO", "OpenPGP", "PGP"):
-                icon_name = "channel-secure-symbolic"
+                icon_name = "lucide-lock-symbolic"
             else:
-                icon_name = "channel-insecure-symbolic"
+                icon_name = "lucide-lock-open-symbolic"
 
         else:
-            icon_name = "channel-insecure-symbolic"
+            icon_name = "lucide-lock-open-symbolic"
             if isinstance(contact, GroupchatContact):
                 tooltip = _("This is a public group chat. Encryption is not available.")
             elif isinstance(contact, GroupchatParticipant):
@@ -658,10 +659,10 @@ class MessageActionsBox(Gtk.Grid, EventHelper, SignalManager):
 
         if authenticated:
             authenticated_string = _("and authenticated")
-            icon_name = "security-high-symbolic"
+            icon_name = "lucide-shield-check-symbolic"
         else:
             authenticated_string = _("and NOT authenticated")
-            icon_name = "security-low-symbolic"
+            icon_name = "lucide-shield-alert-symbolic"
 
         tooltip = _("%(type)s encryption is active %(authenticated)s.") % {
             "type": enc_type,
@@ -686,8 +687,8 @@ class MessageActionsBox(Gtk.Grid, EventHelper, SignalManager):
                 return
 
             if isinstance(contact, BareContact) and contact.is_self:
-                window = open_window("AccountsWindow")
-                window.select_account(contact.account, page="encryption-omemo")
+                window = open_window("Preferences")
+                window.show_page(f"{contact.account}-encryption-omemo")
                 return
 
             open_window(
@@ -869,7 +870,7 @@ class MessageActionsBox(Gtk.Grid, EventHelper, SignalManager):
             log.warning("Could not determine clipboard mime types")
             return
 
-        if "image/png" in mime_types:
+        if "image/png" in mime_types or "image/bmp" in mime_types:
             self._ui.input_overlay.set_visible(True)
             self._ui.input_overlay_label.set_text(_("Processing image…"))
             clipboard.read_texture_async(None, self._on_clipboard_read_texture_finished)
@@ -881,6 +882,9 @@ class MessageActionsBox(Gtk.Grid, EventHelper, SignalManager):
             clipboard.read_value_async(
                 Gdk.FileList, 0, None, self._on_clipboard_read_value_finished
             )
+            return
+
+        log.info("Could not process clipboard mime type %s", mime_types)
 
     def _on_clipboard_read_value_finished(
         self,
