@@ -14,10 +14,12 @@ import sys
 import xml.etree.ElementTree as ET
 from collections.abc import Iterator
 from functools import wraps
+from pathlib import Path
 
 import cairo
 from gi.repository import Adw
 from gi.repository import Gdk
+from gi.repository import Gio
 from gi.repository import GLib
 from gi.repository import Gtk
 from gi.repository import Pango
@@ -34,6 +36,14 @@ from gajim.common.storage.archive import models as mod
 from gajim.common.storage.archive.const import ChatDirection
 from gajim.common.storage.archive.const import MessageType
 from gajim.common.styling import PlainBlock
+from gajim.common.util.decorators import catch_exceptions
+from gajim.common.util.uri import geo_provider_from_location
+from gajim.common.util.uri import GeoUri
+from gajim.common.util.uri import InvalidUri
+from gajim.common.util.uri import parse_uri
+from gajim.common.util.uri import Uri
+from gajim.common.util.uri import UriT
+from gajim.common.util.uri import XmppIri
 
 from gajim.gtk.const import GDK_MEMORY_DEFAULT
 
@@ -138,20 +148,29 @@ def get_avatar_for_message(
     db_row: mod.Message, contact: types.ChatContactT, scale: int, size: AvatarSize
 ) -> Gdk.Texture | None:
 
-    if isinstance(contact, GroupchatContact):
-        name = get_contact_name_for_message(db_row, contact)
-        resource_contact = contact.get_resource(name)
-        return resource_contact.get_avatar(size, scale, add_show=False)
-
     if db_row.direction == ChatDirection.OUTGOING:
-        client = app.get_client(contact.account)
-        self_contact = client.get_module("Contacts").get_contact(
-            client.get_own_jid().bare
+        return app.app.avatar_storage.get_own_avatar_texture(
+            contact.account, size, scale
         )
-        assert isinstance(self_contact, BareContact)
-        return self_contact.get_avatar(size, scale, add_show=False)
 
-    return contact.get_avatar(size, scale, add_show=False)
+    match db_row.type:
+        case MessageType.GROUPCHAT | MessageType.PM:
+
+            if db_row.resource is None:
+                # Message from Groupchat itself
+                assert isinstance(contact, GroupchatContact)
+                return contact.get_avatar(size, scale)
+
+            return app.app.avatar_storage.get_occupant_texture(
+                db_row.remote.jid, db_row.occupant or db_row.resource, size, scale
+            )
+
+        case MessageType.CHAT:
+            assert isinstance(contact, BareContact)
+            return contact.get_avatar(size, scale, add_show=False)
+
+        case _:
+            raise ValueError(f"Unhandled type: {db_row.type}")
 
 
 def make_pango_attributes(block: PlainBlock) -> Pango.AttrList:
@@ -369,3 +388,53 @@ def add_alternative_accelerator(accelerators: list[str]) -> list[str]:
         return [accelerators[0], alternative]
 
     return accelerators
+
+
+@catch_exceptions
+def open_uri(uri: UriT | str) -> None:
+    if isinstance(uri, str):
+        uri = parse_uri(uri)
+
+    match uri:
+        case InvalidUri():
+            log.warning("Failed to open uri: %s", uri.error)
+
+        case XmppIri():
+            app.window.open_xmpp_iri(uri)
+
+        case GeoUri():
+            if Gio.AppInfo.get_default_for_uri_scheme("geo"):
+                open_uri_externally(uri.uri)
+            else:
+                open_uri(geo_provider_from_location(uri.lat, uri.lon))
+
+        case Uri():
+            open_uri_externally(uri.uri)
+
+
+def open_uri_externally(uri: str) -> None:
+    launcher = Gtk.UriLauncher(uri=uri)
+    try:
+        launcher.launch(app.window)
+    except Exception as error:
+        log.warning(
+            "open_uri_externally: Couldn't launch default for %s: %s", uri, error
+        )
+
+
+@catch_exceptions
+def open_file(path: Path, *, show_in_folder: bool = False) -> None:
+    if not path.exists():
+        log.warning("Unable to open file, path %s does not exist", path)
+        return
+
+    path_absolute = path.resolve()
+
+    launcher = Gtk.FileLauncher(file=Gio.File.new_for_path(str(path_absolute)))
+    try:
+        if show_in_folder:
+            launcher.open_containing_folder(app.window)
+        else:
+            launcher.launch(app.window)
+    except Exception as error:
+        log.warning("Unable to open file: %s", error)
